@@ -27,6 +27,16 @@ COOKIECUTTER_REMOTE_URL = (
 COOKIECUTTER_REMOTE_NAME = "cookiecutter-simple-example"
 COOKIECUTTER_REMOTE_VERSION_1 = "c390901c4fd599473bdb95fa4dd3d2a6eb2b34f0"
 COOKIECUTTER_REMOTE_VERSION_2 = "ee8da996b5d74dfcbba5727d7c950c88173dc9ca"
+COOKIECUTTER_CHANGES_TO_COPIER_REMOTE_URL = (
+    "https://github.com/nickderobertis/cookiecutter-changes-to-copier-example"
+)
+COOKIECUTTER_CHANGES_TO_COPIER_REMOTE_NAME = "cookiecutter-changes-to-copier-example"
+COOKIECUTTER_CHANGES_TO_COPIER_REMOTE_VERSION_1 = (
+    "fcaba89a8137dbb08902cb4c02837cb5bfe75b1c"
+)
+COOKIECUTTER_CHANGES_TO_COPIER_REMOTE_VERSION_2 = (
+    "8322fdc62122cfe0e8ca435cdd0d0e231f1d0a43"
+)
 
 COPIERS_DIR = TEMPLATES_DIR / "copiers"
 COPIER_ONE_NAME = "one"
