@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 from enum import Enum
-from typing import List, Final
+from typing import Final, List
 
 import pytest
 
