@@ -1,5 +1,4 @@
 import shutil
-import tempfile
 from copy import deepcopy
 from pathlib import Path
 from typing import List, TypedDict, Union
@@ -9,31 +8,32 @@ import pytest
 from flexlate.finder.specific.cookiecutter import CookiecutterFinder
 from flexlate.finder.specific.copier import CopierFinder
 from flexlate.path_ops import change_directory_to
+from flexlate.temp_path import create_temp_path
 from flexlate.template.cookiecutter import CookiecutterTemplate
 from flexlate.template_path import get_local_repo_path_and_name_cloning_if_repo_url
+from tests import config
 from tests.config import (
     COOKIECUTTER_ONE_DIR,
-    COOKIECUTTER_TWO_DIR,
-    COOKIECUTTER_REMOTE_URL,
-    COOKIECUTTER_REMOTE_VERSION_2,
-    COOKIECUTTER_REMOTE_VERSION_1,
-    COPIER_ONE_DIR,
-    COPIER_REMOTE_VERSION_2,
-    COPIER_REMOTE_VERSION_1,
-    COOKIECUTTER_ONE_VERSION,
     COOKIECUTTER_ONE_MODIFIED_VERSION,
-    COPIER_ONE_VERSION,
-    COPIER_ONE_MODIFIED_VERSION,
-    COPIER_OUTPUT_SUBDIR_DIR,
-    GENERATED_REPO_DIR,
+    COOKIECUTTER_ONE_VERSION,
+    COOKIECUTTER_REMOTE_URL,
+    COOKIECUTTER_REMOTE_VERSION_1,
+    COOKIECUTTER_REMOTE_VERSION_2,
+    COOKIECUTTER_TWO_DIR,
+    COOKIECUTTER_WITH_HOOKS_DIR,
+    COOKIECUTTER_WITH_HOOKS_MODIFIED_VERSION,
+    COOKIECUTTER_WITH_HOOKS_VERSION,
     COPIER_FROM_COOKIECUTTER_ONE_DIR,
     COPIER_FROM_COOKIECUTTER_ONE_VERSION,
-    COOKIECUTTER_WITH_HOOKS_DIR,
+    COPIER_ONE_DIR,
+    COPIER_ONE_MODIFIED_VERSION,
+    COPIER_ONE_VERSION,
+    COPIER_OUTPUT_SUBDIR_DIR,
+    COPIER_REMOTE_VERSION_1,
+    COPIER_REMOTE_VERSION_2,
     COPIER_WITH_TASKS_DIR,
-    COOKIECUTTER_WITH_HOOKS_VERSION,
-    COOKIECUTTER_WITH_HOOKS_MODIFIED_VERSION,
-    COPIER_WITH_TASKS_VERSION,
     COPIER_WITH_TASKS_MODIFIED_VERSION,
+    COPIER_WITH_TASKS_VERSION,
 )
 
 
@@ -95,13 +95,13 @@ def cookiecutter_one_template() -> CookiecutterTemplate:
 def cookiecutter_one_template_in_repo() -> CookiecutterTemplate:
     # NOTE: Must be used in conjunction with an in_repo templated repo because
     # these changes only affect the template and not the generated repo
-    new_folder = GENERATED_REPO_DIR / "templates"
+    new_folder = config.GENERATED_REPO_DIR / "templates"
     new_folder.mkdir(parents=True)
     new_path = new_folder / COOKIECUTTER_ONE_DIR.name
     shutil.copytree(COOKIECUTTER_ONE_DIR, new_path)
     finder = CookiecutterFinder()
-    with change_directory_to(GENERATED_REPO_DIR):
-        relative_path = new_path.relative_to(GENERATED_REPO_DIR)
+    with change_directory_to(config.GENERATED_REPO_DIR):
+        relative_path = new_path.relative_to(config.GENERATED_REPO_DIR)
         template = finder.find(str(relative_path), relative_path)
     yield template
 
@@ -139,8 +139,7 @@ def copier_with_tasks_template() -> CookiecutterTemplate:
 @pytest.fixture()
 def cookiecutter_remote_template() -> CookiecutterTemplate:
     finder = CookiecutterFinder()
-    with tempfile.TemporaryDirectory() as temp_dir:
-        temp_path = Path(temp_dir)
+    with create_temp_path() as temp_path:
         local_path, name = get_local_repo_path_and_name_cloning_if_repo_url(
             COOKIECUTTER_REMOTE_URL, dst_folder=temp_path
         )
@@ -153,8 +152,7 @@ def cookiecutter_remote_template() -> CookiecutterTemplate:
 @pytest.fixture()
 def cookiecutter_remote_version_one_template() -> CookiecutterTemplate:
     finder = CookiecutterFinder()
-    with tempfile.TemporaryDirectory() as temp_dir:
-        temp_path = Path(temp_dir)
+    with create_temp_path() as temp_path:
         local_path, name = get_local_repo_path_and_name_cloning_if_repo_url(
             COOKIECUTTER_REMOTE_URL, COOKIECUTTER_REMOTE_VERSION_1, dst_folder=temp_path
         )
@@ -202,8 +200,7 @@ def cookiecutter_one_modified_template(
     cookiecutter_one_template: CookiecutterTemplate,
 ) -> CookiecutterTemplate:
     template = deepcopy(cookiecutter_one_template)
-    with tempfile.TemporaryDirectory() as directory:
-        out_path = Path(directory)
+    with create_temp_path() as out_path:
         shutil.copytree(template.path, out_path, dirs_exist_ok=True)
         template.path = out_path
         modify_cookiecutter_one(out_path)
