@@ -3,7 +3,7 @@ import contextlib
 import os
 import shutil
 from pathlib import Path
-from typing import Optional, Callable
+from typing import Callable, Optional
 from unittest.mock import patch
 
 import appdirs
@@ -19,34 +19,31 @@ from flexlate.constants import DEFAULT_MERGED_BRANCH_NAME, DEFAULT_TEMPLATE_BRAN
 from flexlate.exc import TriedToCommitButNoChangesException, UnnecessarySyncException
 from flexlate.ext_git import merge_branch_into_current
 from flexlate.main import Flexlate
-from tests.config import (
-    GENERATED_FILES_DIR,
-    COOKIECUTTER_REMOTE_URL,
-    COOKIECUTTER_REMOTE_NAME,
-)
+from tests import config
+from tests.config import COOKIECUTTER_REMOTE_NAME, COOKIECUTTER_REMOTE_URL
+from tests.fixtures.add_mode import *
+from tests.fixtures.cli import *
 from tests.fixtures.git import *
 from tests.fixtures.subdir_style import *
 from tests.fixtures.template import *
-from tests.fixtures.cli import *
-from tests.fixtures.add_mode import *
-from tests.integration.fixtures.template_source import *
 from tests.gitutils import (
     assert_main_commit_message_matches,
-    checkout_new_branch,
     checkout_existing_branch,
+    checkout_new_branch,
 )
 from tests.integration.cli_stub import CLIRunnerException, capture_output
+from tests.integration.fixtures.template_source import *
 from tests.integration.template_source_checks import (
-    assert_project_files_are_correct,
-    assert_project_files_do_not_exist,
-    assert_template_sources_config_is_correct,
-    assert_template_sources_config_is_empty,
+    _get_default_data,
     assert_applied_templates_config_is_correct,
     assert_applied_templates_config_is_empty,
     assert_config_is_correct,
     assert_project_config_is_correct,
-    _get_default_data,
+    assert_project_files_are_correct,
+    assert_project_files_do_not_exist,
     assert_root_template_source_output_is_correct,
+    assert_template_sources_config_is_correct,
+    assert_template_sources_config_is_empty,
 )
 from tests.integration.undoables import UNDOABLE_OPERATIONS
 from tests.test_pusher import add_local_remote_and_check_branches_on_exit
@@ -60,7 +57,8 @@ def test_init_project_and_add_source_and_template(
     fxt = flexlates.flexlate
     no_input = flexlates.type == FlexlateType.APP
     repo = repo_with_placeholder_committed
-    with change_directory_to(GENERATED_REPO_DIR):
+    template_source = template_source.setup_paths()
+    with change_directory_to(config.GENERATED_REPO_DIR):
         fxt.init_project()
         fxt.add_template_source(template_source.path)
         fxt.apply_template_and_add(
@@ -78,7 +76,9 @@ def test_init_project_and_add_source_and_template(
         )
     )
     assert_config_is_correct(
-        at_config_path=GENERATED_REPO_DIR / config_relative_root / "flexlate.json",
+        at_config_path=config.GENERATED_REPO_DIR
+        / config_relative_root
+        / "flexlate.json",
         expect_applied_template_root=template_source.expect_local_applied_template_path,
         expect_data=template_source.input_data,
         template_source_type=template_source.type,
@@ -90,11 +90,10 @@ def test_init_project_and_add_source_and_template(
         render_relative_root_in_template=template_source.render_relative_root_in_template,
     )
 
-    project_config_path = GENERATED_REPO_DIR / "flexlate-project.json"
+    project_config_path = config.GENERATED_REPO_DIR / "flexlate-project.json"
     assert_project_config_is_correct(project_config_path, user=False)
 
 
-@patch.object(appdirs, "user_config_dir", lambda name: GENERATED_FILES_DIR)
 def test_init_project_for_user_and_add_source_and_template(
     flexlates: FlexlateFixture,
     add_mode: AddMode,
@@ -102,40 +101,44 @@ def test_init_project_for_user_and_add_source_and_template(
 ):
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
-    with change_directory_to(GENERATED_REPO_DIR):
-        fxt.init_project(user=True, default_add_mode=add_mode)
-        fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
-        fxt.apply_template_and_add(COOKIECUTTER_REMOTE_NAME, no_input=True)
+    with patch.object(
+        appdirs, "user_config_dir", lambda name: config.GENERATED_FILES_DIR
+    ):
+        with change_directory_to(config.GENERATED_REPO_DIR):
+            fxt.init_project(user=True, default_add_mode=add_mode)
+            fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
+            fxt.apply_template_and_add(COOKIECUTTER_REMOTE_NAME, no_input=True)
 
-    assert_project_files_are_correct()
+        assert_project_files_are_correct()
 
-    if add_mode == AddMode.USER:
-        at_config_root = GENERATED_FILES_DIR
-        ts_config_root = GENERATED_FILES_DIR
-        template_root = GENERATED_REPO_DIR.absolute()
-    elif add_mode == AddMode.PROJECT:
-        at_config_root = GENERATED_REPO_DIR
-        ts_config_root = GENERATED_REPO_DIR
-        template_root = Path(".")
-    elif add_mode == AddMode.LOCAL:
-        at_config_root = GENERATED_REPO_DIR / "abc"
-        ts_config_root = GENERATED_REPO_DIR
-        template_root = Path("..")
-    else:
-        raise ValueError(f"unsupported add mode {add_mode}")
+        if add_mode == AddMode.USER:
+            at_config_root = config.GENERATED_FILES_DIR
+            ts_config_root = config.GENERATED_FILES_DIR
+            template_root = config.GENERATED_REPO_DIR.absolute()
+        elif add_mode == AddMode.PROJECT:
+            at_config_root = config.GENERATED_REPO_DIR
+            ts_config_root = config.GENERATED_REPO_DIR
+            template_root = Path(".")
+        elif add_mode == AddMode.LOCAL:
+            at_config_root = config.GENERATED_REPO_DIR / "abc"
+            ts_config_root = config.GENERATED_REPO_DIR
+            template_root = Path("..")
+        else:
+            raise ValueError(f"unsupported add mode {add_mode}")
 
-    assert_config_is_correct(
-        at_config_path=at_config_root / "flexlate.json",
-        ts_config_path=ts_config_root / "flexlate.json",
-        expect_applied_template_root=template_root,
-        expect_add_mode=add_mode,
-    )
+        assert_config_is_correct(
+            at_config_path=at_config_root / "flexlate.json",
+            ts_config_path=ts_config_root / "flexlate.json",
+            expect_applied_template_root=template_root,
+            expect_add_mode=add_mode,
+        )
 
-    project_config_path = GENERATED_FILES_DIR / "flexlate-project.json"
-    assert_project_config_is_correct(project_config_path, user=True, add_mode=add_mode)
+        project_config_path = config.GENERATED_FILES_DIR / "flexlate-project.json"
+        assert_project_config_is_correct(
+            project_config_path, user=True, add_mode=add_mode
+        )
 
 
-@patch.object(appdirs, "user_config_dir", lambda name: GENERATED_FILES_DIR)
 def test_init_project_and_add_source_and_template_in_subdir(
     flexlates: FlexlateFixture,
     add_mode: AddMode,
@@ -146,85 +149,90 @@ def test_init_project_and_add_source_and_template_in_subdir(
     fxt = flexlates.flexlate
     template_source = template_source_one_remote_and_all_local_relative
     repo = repo_with_placeholder_committed
+    template_source = template_source.setup_paths()
 
-    with change_directory_to(GENERATED_REPO_DIR):
-        fxt.init_project(default_add_mode=add_mode)
-        fxt.add_template_source(template_source.path)
-        subdir = GENERATED_REPO_DIR / "subdir1" / "subdir2"
-        subdir.mkdir(parents=True)
-        if subdir_style == SubdirStyle.CD:
-            with change_directory_to(subdir):
-                fxt.apply_template_and_add(template_source.name, no_input=True)
-        elif subdir_style == SubdirStyle.PROVIDE_RELATIVE:
-            fxt.apply_template_and_add(
-                template_source.name,
-                no_input=True,
-                out_root=subdir.relative_to(os.getcwd()),
-            )
-        elif subdir_style == SubdirStyle.PROVIDE_ABSOLUTE:
-            fxt.apply_template_and_add(
-                template_source.name, no_input=True, out_root=subdir.absolute()
-            )
+    with patch.object(
+        appdirs, "user_config_dir", lambda name: config.GENERATED_FILES_DIR
+    ):
+        with change_directory_to(config.GENERATED_REPO_DIR):
+            fxt.init_project(default_add_mode=add_mode)
+            fxt.add_template_source(template_source.path)
+            subdir = config.GENERATED_REPO_DIR / "subdir1" / "subdir2"
+            subdir.mkdir(parents=True)
+            if subdir_style == SubdirStyle.CD:
+                with change_directory_to(subdir):
+                    fxt.apply_template_and_add(template_source.name, no_input=True)
+            elif subdir_style == SubdirStyle.PROVIDE_RELATIVE:
+                fxt.apply_template_and_add(
+                    template_source.name,
+                    no_input=True,
+                    out_root=subdir.relative_to(os.getcwd()),
+                )
+            elif subdir_style == SubdirStyle.PROVIDE_ABSOLUTE:
+                fxt.apply_template_and_add(
+                    template_source.name, no_input=True, out_root=subdir.absolute()
+                )
 
-    assert_project_files_are_correct(
-        subdir,
-        template_source_type=template_source.type,
-        version=template_source.default_version,
-    )
-
-    config_relative_root = (
-        template_source.evaluated_render_relative_root_in_output_creator(
-            _get_default_data(template_source.type)
+        assert_project_files_are_correct(
+            subdir,
+            template_source_type=template_source.type,
+            version=template_source.default_version,
         )
-    )
 
-    if add_mode == AddMode.LOCAL:
-        applied_config_dir = subdir / config_relative_root
-        expect_applied_template_root = (
-            template_source.expect_local_applied_template_path
-        )
-        template_sources_config_dir = GENERATED_REPO_DIR
-        expect_template_source_path = template_source.path
-    elif add_mode == AddMode.PROJECT:
-        applied_config_dir = GENERATED_REPO_DIR
-        expect_applied_template_root = subdir.relative_to(GENERATED_REPO_DIR)
-        template_sources_config_dir = GENERATED_REPO_DIR
-        expect_template_source_path = template_source.path
-    elif add_mode == AddMode.USER:
-        applied_config_dir = GENERATED_FILES_DIR
-        expect_applied_template_root = subdir.absolute()
-        template_sources_config_dir = GENERATED_FILES_DIR
-        if template_source.is_local_template:
-            # Move the original directory down a level in the relative path
-            # E.g. move ../../input_files/templates/cookiecutters/one to ../input_files/templates/cookiecutters/one
-            expect_template_source_path = str(
-                Path(*Path(template_source.path).parts[1:])
+        config_relative_root = (
+            template_source.evaluated_render_relative_root_in_output_creator(
+                _get_default_data(template_source.type)
             )
-        else:
+        )
+
+        if add_mode == AddMode.LOCAL:
+            applied_config_dir = subdir / config_relative_root
+            expect_applied_template_root = (
+                template_source.expect_local_applied_template_path
+            )
+            template_sources_config_dir = config.GENERATED_REPO_DIR
             expect_template_source_path = template_source.path
-    else:
-        raise ValueError(f"unsupported add mode {add_mode}")
+        elif add_mode == AddMode.PROJECT:
+            applied_config_dir = config.GENERATED_REPO_DIR
+            expect_applied_template_root = subdir.relative_to(config.GENERATED_REPO_DIR)
+            template_sources_config_dir = config.GENERATED_REPO_DIR
+            expect_template_source_path = template_source.path
+        elif add_mode == AddMode.USER:
+            applied_config_dir = config.GENERATED_FILES_DIR
+            expect_applied_template_root = subdir.absolute()
+            template_sources_config_dir = config.GENERATED_FILES_DIR
+            if template_source.is_relative_template:
+                # Move the original directory to be relative to the user config dir
+                expect_template_source_path = os.path.relpath(
+                    template_source.path, config.GENERATED_REPO_DIR
+                )
+            else:
+                expect_template_source_path = template_source.path
+        else:
+            raise ValueError(f"unsupported add mode {add_mode}")
 
-    assert_template_sources_config_is_correct(
-        template_sources_config_dir / "flexlate.json",
-        version=template_source.default_version,
-        name=template_source.name,
-        url=template_source.url,
-        path=expect_template_source_path,
-        render_relative_root_in_output=template_source.render_relative_root_in_output,
-        render_relative_root_in_template=template_source.render_relative_root_in_template,
-    )
-    assert_applied_templates_config_is_correct(
-        applied_config_dir / "flexlate.json",
-        expect_applied_template_root=expect_applied_template_root,
-        version=template_source.default_version,
-        template_source_type=template_source.type,
-        name=template_source.name,
-        expect_add_mode=add_mode,
-    )
+        assert_template_sources_config_is_correct(
+            template_sources_config_dir / "flexlate.json",
+            version=template_source.default_version,
+            name=template_source.name,
+            url=template_source.url,
+            path=expect_template_source_path,
+            render_relative_root_in_output=template_source.render_relative_root_in_output,
+            render_relative_root_in_template=template_source.render_relative_root_in_template,
+        )
+        assert_applied_templates_config_is_correct(
+            applied_config_dir / "flexlate.json",
+            expect_applied_template_root=expect_applied_template_root,
+            version=template_source.default_version,
+            template_source_type=template_source.type,
+            name=template_source.name,
+            expect_add_mode=add_mode,
+        )
 
-    project_config_path = GENERATED_REPO_DIR / "flexlate-project.json"
-    assert_project_config_is_correct(project_config_path, user=False, add_mode=add_mode)
+        project_config_path = config.GENERATED_REPO_DIR / "flexlate-project.json"
+        assert_project_config_is_correct(
+            project_config_path, user=False, add_mode=add_mode
+        )
 
 
 @pytest.mark.parametrize("update_from_subdir", [False, True])
@@ -237,9 +245,10 @@ def test_update_project(
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
     template_source = template_source_with_relative
+    template_source = template_source.setup_paths()
 
     no_input = flexlates.type == FlexlateType.APP
-    subdir = GENERATED_REPO_DIR / "subdir1" / "subdir2"
+    subdir = config.GENERATED_REPO_DIR / "subdir1" / "subdir2"
     subdir.mkdir(parents=True)
 
     def assert_root_template_output_is_correct(
@@ -290,7 +299,7 @@ def test_update_project(
         )
         assert_template_sources_config_is_empty(at_config_path)
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(config.GENERATED_REPO_DIR):
         fxt.init_project()
         fxt.add_template_source(
             template_source.path, target_version=template_source.version_1
@@ -308,7 +317,7 @@ def test_update_project(
             )
             assert_subdir_template_output_is_correct()
 
-        update_directory = subdir if update_from_subdir else GENERATED_REPO_DIR
+        update_directory = subdir if update_from_subdir else config.GENERATED_REPO_DIR
         with change_directory_to(update_directory):
             # First update does nothing, because version is at target version
             # When using app, it will throw an error
@@ -355,7 +364,7 @@ def test_update_project(
         after_version_update=True, after_data_update=True
     )
 
-    project_config_path = GENERATED_REPO_DIR / "flexlate-project.json"
+    project_config_path = config.GENERATED_REPO_DIR / "flexlate-project.json"
     assert_project_config_is_correct(project_config_path, user=False)
 
 
@@ -371,7 +380,7 @@ def test_update_one_template(
     with template_source_with_temp_dir_if_local_template(
         COPIER_LOCAL_FIXTURE
     ) as template_source:
-        with change_directory_to(GENERATED_REPO_DIR):
+        with change_directory_to(config.GENERATED_REPO_DIR):
             fxt.init_project()
             # Add both template sources and outputs in the main directory at version 1
             for i, ts in enumerate([template_source, non_update_template_source]):
@@ -458,11 +467,10 @@ def test_update_one_template(
             target_version=non_update_template_source.version_1,
         )
 
-        project_config_path = GENERATED_REPO_DIR / "flexlate-project.json"
+        project_config_path = config.GENERATED_REPO_DIR / "flexlate-project.json"
         assert_project_config_is_correct(project_config_path, user=False)
 
 
-@patch.object(appdirs, "user_config_dir", lambda name: GENERATED_FILES_DIR)
 @pytest.mark.parametrize("user", [False, True])
 def test_remove_template_source(
     user: bool,
@@ -474,63 +482,73 @@ def test_remove_template_source(
     repo = repo_with_placeholder_committed
     fxt = flexlates.flexlate
     config_root = (
-        GENERATED_FILES_DIR if add_mode == AddMode.USER else GENERATED_REPO_DIR
+        config.GENERATED_FILES_DIR
+        if add_mode == AddMode.USER
+        else config.GENERATED_REPO_DIR
+    )
+    project_config_root = (
+        config.GENERATED_FILES_DIR if user else config.GENERATED_REPO_DIR
     )
-    project_config_root = GENERATED_FILES_DIR if user else GENERATED_REPO_DIR
     config_path = config_root / "flexlate.json"
     project_config_path = project_config_root / "flexlate-project.json"
-    with change_directory_to(GENERATED_REPO_DIR):
-        fxt.init_project(user=user, default_add_mode=add_mode)
-        fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
-        assert config_path.exists()
-        fxt.remove_template_source(COOKIECUTTER_REMOTE_NAME)
-        assert not config_path.exists()
-
-    assert_project_config_is_correct(project_config_path, user=user, add_mode=add_mode)
-
-    # Works for main dir, now try subdir
-    subdir = GENERATED_REPO_DIR / "subdir1" / "subdir2"
-    subdir.mkdir(parents=True)
-    subdir_config_root: Path
-    if add_mode == AddMode.USER:
-        subdir_config_root = GENERATED_FILES_DIR
-    elif add_mode == AddMode.LOCAL:
-        subdir_config_root = subdir
-    elif add_mode == AddMode.PROJECT:
-        subdir_config_root = GENERATED_REPO_DIR
-    else:
-        raise ValueError("unsupported add mode")
-    subdir_config_path = subdir_config_root / "flexlate.json"
-
-    if subdir_style == SubdirStyle.CD:
-        with change_directory_to(subdir):
+    with patch.object(
+        appdirs, "user_config_dir", lambda name: config.GENERATED_FILES_DIR
+    ):
+        with change_directory_to(config.GENERATED_REPO_DIR):
+            fxt.init_project(user=user, default_add_mode=add_mode)
             fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
-            assert subdir_config_path.exists()
+            assert config_path.exists()
             fxt.remove_template_source(COOKIECUTTER_REMOTE_NAME)
+            assert not config_path.exists()
+
+        assert_project_config_is_correct(
+            project_config_path, user=user, add_mode=add_mode
+        )
+
+        # Works for main dir, now try subdir
+        subdir = config.GENERATED_REPO_DIR / "subdir1" / "subdir2"
+        subdir.mkdir(parents=True)
+        subdir_config_root: Path
+        if add_mode == AddMode.USER:
+            subdir_config_root = config.GENERATED_FILES_DIR
+        elif add_mode == AddMode.LOCAL:
+            subdir_config_root = subdir
+        elif add_mode == AddMode.PROJECT:
+            subdir_config_root = config.GENERATED_REPO_DIR
+        else:
+            raise ValueError("unsupported add mode")
+        subdir_config_path = subdir_config_root / "flexlate.json"
+
+        if subdir_style == SubdirStyle.CD:
+            with change_directory_to(subdir):
+                fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
+                assert subdir_config_path.exists()
+                fxt.remove_template_source(COOKIECUTTER_REMOTE_NAME)
+                assert not subdir_config_path.exists()
+        elif subdir_style == SubdirStyle.PROVIDE_RELATIVE:
+            out_root = Path(os.path.relpath(subdir, os.getcwd()))
+            fxt.add_template_source(
+                COOKIECUTTER_REMOTE_URL,
+                template_root=out_root,
+            )
+            assert subdir_config_path.exists()
+            fxt.remove_template_source(COOKIECUTTER_REMOTE_NAME, template_root=out_root)
             assert not subdir_config_path.exists()
-    elif subdir_style == SubdirStyle.PROVIDE_RELATIVE:
-        out_root = subdir.relative_to(os.getcwd())
-        fxt.add_template_source(
-            COOKIECUTTER_REMOTE_URL,
-            template_root=out_root,
+        elif subdir_style == SubdirStyle.PROVIDE_ABSOLUTE:
+            out_root = subdir.absolute()
+            fxt.add_template_source(
+                COOKIECUTTER_REMOTE_URL,
+                template_root=out_root,
+            )
+            assert subdir_config_path.exists()
+            fxt.remove_template_source(COOKIECUTTER_REMOTE_NAME, template_root=out_root)
+            assert not subdir_config_path.exists()
+
+        assert_project_config_is_correct(
+            project_config_path, user=user, add_mode=add_mode
         )
-        assert subdir_config_path.exists()
-        fxt.remove_template_source(COOKIECUTTER_REMOTE_NAME, template_root=out_root)
-        assert not subdir_config_path.exists()
-    elif subdir_style == SubdirStyle.PROVIDE_ABSOLUTE:
-        out_root = subdir.absolute()
-        fxt.add_template_source(
-            COOKIECUTTER_REMOTE_URL,
-            template_root=out_root,
-        )
-        assert subdir_config_path.exists()
-        fxt.remove_template_source(COOKIECUTTER_REMOTE_NAME, template_root=out_root)
-        assert not subdir_config_path.exists()
-
-    assert_project_config_is_correct(project_config_path, user=user, add_mode=add_mode)
 
 
-@patch.object(appdirs, "user_config_dir", lambda name: GENERATED_FILES_DIR)
 @pytest.mark.parametrize("user", [False, True])
 def test_remove_applied_template(
     user: bool,
@@ -542,143 +560,160 @@ def test_remove_applied_template(
     fxt = flexlates.flexlate
     no_input = flexlates.type == FlexlateType.APP
     config_root = (
-        GENERATED_FILES_DIR if add_mode == AddMode.USER else GENERATED_REPO_DIR
+        config.GENERATED_FILES_DIR
+        if add_mode == AddMode.USER
+        else config.GENERATED_REPO_DIR
+    )
+    project_config_root = (
+        config.GENERATED_FILES_DIR if user else config.GENERATED_REPO_DIR
     )
-    project_config_root = GENERATED_FILES_DIR if user else GENERATED_REPO_DIR
     config_path = config_root / "flexlate.json"
     project_config_path = project_config_root / "flexlate-project.json"
     expect_data: CookiecutterRemoteTemplateData = dict(name="woo", key="it works")
-    with change_directory_to(GENERATED_REPO_DIR):
-        fxt.init_project(user=user, default_add_mode=add_mode)
-        fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
-        fxt.apply_template_and_add(
-            COOKIECUTTER_REMOTE_NAME, data=expect_data, no_input=no_input
-        )
-        assert_project_files_are_correct(expect_data=expect_data)
-        fxt.remove_applied_template_and_output(COOKIECUTTER_REMOTE_NAME)
+    with patch.object(
+        appdirs, "user_config_dir", lambda name: config.GENERATED_FILES_DIR
+    ):
+        with change_directory_to(config.GENERATED_REPO_DIR):
+            fxt.init_project(user=user, default_add_mode=add_mode)
+            fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
+            fxt.apply_template_and_add(
+                COOKIECUTTER_REMOTE_NAME, data=expect_data, no_input=no_input
+            )
+            assert_project_files_are_correct(expect_data=expect_data)
+            fxt.remove_applied_template_and_output(COOKIECUTTER_REMOTE_NAME)
 
-        assert_project_files_do_not_exist(expect_data=expect_data)
+            assert_project_files_do_not_exist(expect_data=expect_data)
+            assert_project_config_is_correct(
+                project_config_path, user=user, add_mode=add_mode
+            )
+            assert_applied_templates_config_is_empty(config_path)
+
+            # Works for main dir, now try subdir
+            subdir = config.GENERATED_REPO_DIR / "subdir1" / "subdir2"
+            subdir.mkdir(parents=True)
+            if subdir_style == SubdirStyle.CD:
+                with change_directory_to(subdir):
+                    fxt.apply_template_and_add(
+                        COOKIECUTTER_REMOTE_NAME, data=expect_data, no_input=no_input
+                    )
+                    fxt.remove_applied_template_and_output(COOKIECUTTER_REMOTE_NAME)
+            elif subdir_style == SubdirStyle.PROVIDE_RELATIVE:
+                out_root = subdir.relative_to(os.getcwd())
+                fxt.apply_template_and_add(
+                    COOKIECUTTER_REMOTE_NAME,
+                    data=expect_data,
+                    no_input=no_input,
+                    out_root=out_root,
+                )
+                fxt.remove_applied_template_and_output(
+                    COOKIECUTTER_REMOTE_NAME, out_root=out_root
+                )
+            elif subdir_style == SubdirStyle.PROVIDE_ABSOLUTE:
+                out_root = subdir.absolute()
+                fxt.apply_template_and_add(
+                    COOKIECUTTER_REMOTE_NAME,
+                    data=expect_data,
+                    no_input=no_input,
+                    out_root=out_root,
+                )
+                fxt.remove_applied_template_and_output(
+                    COOKIECUTTER_REMOTE_NAME, out_root=out_root
+                )
+
+        assert_project_files_do_not_exist(subdir, expect_data=expect_data)
         assert_project_config_is_correct(
             project_config_path, user=user, add_mode=add_mode
         )
-        assert_applied_templates_config_is_empty(config_path)
-
-        # Works for main dir, now try subdir
-        subdir = GENERATED_REPO_DIR / "subdir1" / "subdir2"
-        subdir.mkdir(parents=True)
-        if subdir_style == SubdirStyle.CD:
-            with change_directory_to(subdir):
-                fxt.apply_template_and_add(
-                    COOKIECUTTER_REMOTE_NAME, data=expect_data, no_input=no_input
-                )
-                fxt.remove_applied_template_and_output(COOKIECUTTER_REMOTE_NAME)
-        elif subdir_style == SubdirStyle.PROVIDE_RELATIVE:
-            out_root = subdir.relative_to(os.getcwd())
-            fxt.apply_template_and_add(
-                COOKIECUTTER_REMOTE_NAME,
-                data=expect_data,
-                no_input=no_input,
-                out_root=out_root,
-            )
-            fxt.remove_applied_template_and_output(
-                COOKIECUTTER_REMOTE_NAME, out_root=out_root
-            )
-        elif subdir_style == SubdirStyle.PROVIDE_ABSOLUTE:
-            out_root = subdir.absolute()
-            fxt.apply_template_and_add(
-                COOKIECUTTER_REMOTE_NAME,
-                data=expect_data,
-                no_input=no_input,
-                out_root=out_root,
-            )
-            fxt.remove_applied_template_and_output(
-                COOKIECUTTER_REMOTE_NAME, out_root=out_root
-            )
-
-    assert_project_files_do_not_exist(subdir, expect_data=expect_data)
-    assert_project_config_is_correct(project_config_path, user=user, add_mode=add_mode)
-    assert not (subdir / "flexlate.json").exists()
+        assert not (subdir / "flexlate.json").exists()
 
 
-@patch.object(appdirs, "user_config_dir", lambda name: GENERATED_FILES_DIR)
 def test_undo(
     flexlates: FlexlateFixture,
     repo_with_placeholder_committed: Repo,
 ):
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
-    with change_directory_to(GENERATED_REPO_DIR):
-        fxt.init_project()
-        fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
-        fxt.apply_template_and_add(COOKIECUTTER_REMOTE_NAME, no_input=True)
-        # Work in a subdirectory so that we can run all operations.
-        # Commit a file so that the folder will persist and ensure that
-        # the file is never removed
-        subdir = GENERATED_REPO_DIR / "subdir"
-        subdir.mkdir()
-        subdir_placeholder_path = (subdir / "some-file.txt").resolve()
-        subdir_placeholder_path.write_text("something")
-        manual_commit_message = "Add a placeholder in a subdir"
-        stage_and_commit_all(repo, manual_commit_message)
-        # Add an operation that will be undone
-        with change_directory_to(subdir):
-            # One check being careful about the input files, just to make sure
-            # something is happening
+    with patch.object(
+        appdirs, "user_config_dir", lambda name: config.GENERATED_FILES_DIR
+    ):
+        with change_directory_to(config.GENERATED_REPO_DIR):
+            fxt.init_project()
+            fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
             fxt.apply_template_and_add(COOKIECUTTER_REMOTE_NAME, no_input=True)
-            config_path = subdir / "abc" / "flexlate.json"
-            assert_project_files_are_correct(subdir)
-            assert_applied_templates_config_is_correct(
-                config_path, expect_applied_template_root=Path("..")
-            )
-            fxt.undo()
-            assert_project_files_do_not_exist(subdir)
-            assert not config_path.exists()
-            assert subdir_placeholder_path.read_text() == "something"
-            # Now check everything just to make sure it can be undone
-            is_cli = flexlates.type == FlexlateType.CLI
-            for operation in UNDOABLE_OPERATIONS:
-                operation.operation(fxt, is_cli)
-                fxt.undo(num_operations=operation.num_transactions)
+            # Work in a subdirectory so that we can run all operations.
+            # Commit a file so that the folder will persist and ensure that
+            # the file is never removed
+            subdir = config.GENERATED_REPO_DIR / "subdir"
+            subdir.mkdir()
+            subdir_placeholder_path = (subdir / "some-file.txt").resolve()
+            subdir_placeholder_path.write_text("something")
+            manual_commit_message = "Add a placeholder in a subdir"
+            stage_and_commit_all(repo, manual_commit_message)
+            # Add an operation that will be undone
+            with change_directory_to(subdir):
+                # One check being careful about the input files, just to make sure
+                # something is happening
+                fxt.apply_template_and_add(COOKIECUTTER_REMOTE_NAME, no_input=True)
+                config_path = subdir / "abc" / "flexlate.json"
+                assert_project_files_are_correct(subdir)
+                assert_applied_templates_config_is_correct(
+                    config_path, expect_applied_template_root=Path("..")
+                )
+                fxt.undo()
                 assert_project_files_do_not_exist(subdir)
                 assert not config_path.exists()
                 assert subdir_placeholder_path.read_text() == "something"
+                # Now check everything just to make sure it can be undone
+                is_cli = flexlates.type == FlexlateType.CLI
+                for operation in UNDOABLE_OPERATIONS:
+                    operation.operation(fxt, is_cli)
+                    fxt.undo(num_operations=operation.num_transactions)
+                    assert_project_files_do_not_exist(subdir)
+                    assert not config_path.exists()
+                    assert subdir_placeholder_path.read_text() == "something"
 
-    def assert_merged_commit_history_is_correct():
-        assert_main_commit_message_matches(repo.commit().message, manual_commit_message)
+        def assert_merged_commit_history_is_correct():
+            assert_main_commit_message_matches(
+                repo.commit().message, manual_commit_message
+            )
+            assert len(repo.commit().parents) == 1
+            parent = repo.commit().parents[0]
+            assert_main_commit_message_matches(
+                parent.message, "Update flexlate templates"
+            )
+
+        assert_merged_commit_history_is_correct()
+        assert_project_files_are_correct()
+        assert_config_is_correct(
+            at_config_path=config.GENERATED_REPO_DIR / "abc" / "flexlate.json",
+            expect_applied_template_root=Path(".."),
+        )
+        assert_project_config_is_correct()
+
+        merged_branch_name = get_flexlate_branch_name(repo, DEFAULT_MERGED_BRANCH_NAME)
+        template_branch_name = get_flexlate_branch_name(
+            repo, DEFAULT_TEMPLATE_BRANCH_NAME
+        )
+
+        for branch_name in [merged_branch_name, template_branch_name]:
+            branch = repo.branches[branch_name]  # type: ignore
+            branch.checkout()
+
+        merged_branch = repo.branches[merged_branch_name]  # type: ignore
+        merged_branch.checkout()
+        assert_merged_commit_history_is_correct()
+
+        template_branch = repo.branches[template_branch_name]  # type: ignore
+        template_branch.checkout()
+
+        assert_main_commit_message_matches(
+            repo.commit().message, "Update flexlate templates"
+        )
         assert len(repo.commit().parents) == 1
         parent = repo.commit().parents[0]
-        assert_main_commit_message_matches(parent.message, "Update flexlate templates")
-
-    assert_merged_commit_history_is_correct()
-    assert_project_files_are_correct()
-    assert_config_is_correct(
-        at_config_path=GENERATED_REPO_DIR / "abc" / "flexlate.json",
-        expect_applied_template_root=Path(".."),
-    )
-    assert_project_config_is_correct()
-
-    merged_branch_name = get_flexlate_branch_name(repo, DEFAULT_MERGED_BRANCH_NAME)
-    template_branch_name = get_flexlate_branch_name(repo, DEFAULT_TEMPLATE_BRANCH_NAME)
-
-    for branch_name in [merged_branch_name, template_branch_name]:
-        branch = repo.branches[branch_name]  # type: ignore
-        branch.checkout()
-
-    merged_branch = repo.branches[merged_branch_name]  # type: ignore
-    merged_branch.checkout()
-    assert_merged_commit_history_is_correct()
-
-    template_branch = repo.branches[template_branch_name]  # type: ignore
-    template_branch.checkout()
-
-    assert_main_commit_message_matches(
-        repo.commit().message, "Update flexlate templates"
-    )
-    assert len(repo.commit().parents) == 1
-    parent = repo.commit().parents[0]
-    assert_main_commit_message_matches(
-        parent.message, "Applied template cookiecutter-simple-example to ."
-    )
+        assert_main_commit_message_matches(
+            parent.message, "Applied template cookiecutter-simple-example to ."
+        )
 
 
 def test_init_project_from_template(
@@ -687,10 +722,11 @@ def test_init_project_from_template(
 ):
     fxt = flexlates.flexlate
     template_source = template_source_with_relative
+    template_source = template_source.setup_paths()
 
     no_input = flexlates.type == FlexlateType.APP
-    with change_directory_to(GENERATED_FILES_DIR):
-        subdir = GENERATED_FILES_DIR / "subdir" / "nested"
+    with change_directory_to(config.GENERATED_FILES_DIR):
+        subdir = config.GENERATED_FILES_DIR / "subdir" / "nested"
         fxt.init_project_from(
             template_source.path,
             path=subdir,
@@ -750,9 +786,9 @@ def test_sync_manually_remove_applied_template(
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
 
-    output_folder = GENERATED_REPO_DIR / "abc"
+    output_folder = config.GENERATED_REPO_DIR / "abc"
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(config.GENERATED_REPO_DIR):
         fxt.init_project()
         fxt.add_template_source(COOKIECUTTER_REMOTE_URL)
         fxt.apply_template_and_add(COOKIECUTTER_REMOTE_NAME, no_input=True)
@@ -780,10 +816,10 @@ def test_merge(flexlates: FlexlateFixture, repo_with_placeholder_committed: Repo
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(config.GENERATED_REPO_DIR):
         fxt.init_project()
         # Make a dummy change
-        dummy_file = GENERATED_REPO_DIR / "something.txt"
+        dummy_file = config.GENERATED_REPO_DIR / "something.txt"
         dummy_file.write_text("text")
         stage_and_commit_all(repo, "Add a dummy change to the main branch")
         with _checkout_new_branch_that_merges_back(repo, fxt, "add-source"):
@@ -811,10 +847,10 @@ def test_push(flexlates: FlexlateFixture, repo_with_placeholder_committed: Repo)
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(config.GENERATED_REPO_DIR):
         fxt.init_project()
         # Make a dummy change
-        dummy_file = GENERATED_REPO_DIR / "something.txt"
+        dummy_file = config.GENERATED_REPO_DIR / "something.txt"
         dummy_file.write_text("text")
         stage_and_commit_all(repo, "Add a dummy change to the main branch")
         with _checkout_new_branch_that_merges_back(repo, fxt, "add-source"):
@@ -851,6 +887,7 @@ def test_check(
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
     template_source: TemplateSourceFixture = COPIER_REMOTE_FIXTURE
+    template_source = template_source.setup_paths()
 
     def _run_check_and_asserter_on_output(
         stdout_asserter: Callable[[str], None], stderr_asserter: Callable[[str], None]
@@ -894,7 +931,7 @@ def test_check(
             _assert_no_output,
         )
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(config.GENERATED_REPO_DIR):
         fxt.init_project()
         fxt.add_template_source(
             template_source.path, target_version=template_source.version_1
@@ -921,9 +958,10 @@ def test_bootstrap(
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
     template_source = template_source_with_relative
+    template_source = template_source.setup_paths()
     no_input = flexlates.type == FlexlateType.APP
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(config.GENERATED_REPO_DIR):
         template_source.render_without_flexlate()
         stage_and_commit_all(
             repo, f"Render files with {template_source.template_type.value}"
@@ -955,8 +993,9 @@ def test_update_target_version(
 ):
     fxt = flexlates.flexlate
     repo = repo_with_placeholder_committed
+    template_source = template_source.setup_paths()
 
-    config_path = GENERATED_REPO_DIR / "flexlate.json"
+    config_path = config.GENERATED_REPO_DIR / "flexlate.json"
 
     def assert_target_version_is(version: Optional[str]):
         config = FlexlateConfig.load(config_path)
@@ -964,7 +1003,7 @@ def test_update_target_version(
         ts = config.template_sources[0]
         assert ts.target_version == version
 
-    with change_directory_to(GENERATED_REPO_DIR):
+    with change_directory_to(config.GENERATED_REPO_DIR):
         fxt.init_project()
         fxt.add_template_source(template_source.path)
         assert_target_version_is(None)
